@@ -1,14 +1,13 @@
 //! ECDSA signing key
 
-use super::{Curve, CurveAlg, Signature, VerifyingKey};
+use super::{CurveAlg, PrimeCurve, Signature, VerifyingKey};
 use crate::signature::{Error, Signature as _, Signer};
 use ::ecdsa::{
-    elliptic_curve::sec1::{UncompressedPointSize, UntaggedPointSize},
+    elliptic_curve::{sec1, FieldSize},
     SignatureSize,
 };
 use core::marker::PhantomData;
-use core::ops::Add;
-use generic_array::{typenum::U1, ArrayLength};
+use generic_array::ArrayLength;
 use ring::{
     self,
     rand::SystemRandom,
@@ -18,7 +17,7 @@ use ring::{
 /// ECDSA signing key. Generic over elliptic curves.
 pub struct SigningKey<C>
 where
-    C: Curve + CurveAlg,
+    C: PrimeCurve + CurveAlg,
     SignatureSize<C>: ArrayLength<u8>,
 {
     /// *ring* ECDSA keypair
@@ -33,7 +32,7 @@ where
 
 impl<C> SigningKey<C>
 where
-    C: Curve + CurveAlg,
+    C: PrimeCurve + CurveAlg,
     SignatureSize<C>: ArrayLength<u8>,
 {
     /// Initialize a [`SigningKey`] from a PKCS#8-encoded private key
@@ -61,8 +60,7 @@ where
     /// Get the [`VerifyingKey`] for this [`SigningKey`]
     pub fn verify_key(&self) -> VerifyingKey<C>
     where
-        UntaggedPointSize<C>: Add<U1> + ArrayLength<u8>,
-        UncompressedPointSize<C>: ArrayLength<u8>,
+        FieldSize<C>: sec1::ModulusSize,
     {
         VerifyingKey::new(self.keypair.public_key().as_ref()).unwrap()
     }
@@ -70,7 +68,7 @@ where
 
 impl<C> Signer<Signature<C>> for SigningKey<C>
 where
-    C: Curve + CurveAlg,
+    C: PrimeCurve + CurveAlg,
     SignatureSize<C>: ArrayLength<u8>,
 {
     fn try_sign(&self, msg: &[u8]) -> Result<Signature<C>, Error> {
